==> tetzle_2.1.6.orig.tar.gz: tetzle-2.1.6/translations/tetzle_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Otwórz obraz</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Skośne krawędzie</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Cienie upuszczania</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Kolory</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Tło:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Cień:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Zaznaczone:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Brak obrazu.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Proszę czekać</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Ładowanie obrazu...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Tworzenie puzzli...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Tworzenie części...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Ładowanie puzzli...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Nieznany format danych</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Nieznany element &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Błąd parsowania pliku XML.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Ładowanie części...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Pobieranie części...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Umieszczanie części...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sukces</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Wybierz grę</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Obecne gry</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Nowa gra</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Właściwości obrazu</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nazwa:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Tagi</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Wybierz język programu:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Język systemowy&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Uwaga</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Proszę ponownie uruchomić ten program, aby zastosować zmianę języka.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Dodaj obraz</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Usuń obraz</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Właściwości obrazu</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 części</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Kopiowanie obrazów...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Usunąć wybrany obraz?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Usunąć wybrany obraz?

Istniejące zapisane gry, które używają tego obrazu, zostaną również usunięte.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Bez tytułu</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Bez tytułu</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 części %2 %3% kompletne</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Usuń grę</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Usunąć wybraną grę?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Przegląd</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Dodaj tag</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Usuń tag</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Bez tagów</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Wszystkie obrazy</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Bez tytułu %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pytanie</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Usunąć wybrany tag?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Przepraszamy</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Tag o takiej nazwie już istnieje.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Gra</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Pobierz części</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Zakończ</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>W&amp;ybierz...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Widok</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Przybliż</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Oddal</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>&amp;Najlepsze dopasowanie</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Pokaż p&amp;odgląd</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>Pełny &amp;ekran</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ustawienia</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>Wy&amp;gląd...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Język...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Sterowanie</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Sterowanie</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Podnoszenie części:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Lewy przycisk myszy lub spacja</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Upuszczanie części:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Wybór części:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Przeciągając lewym przyciskiem myszy</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Obróć części:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Prawy przycisk myszy, Ctrl + Lewy przycisk myszy lub R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Przeciąganie puzzli:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Środkowy przycisk myszy, Shift + Lewy przycisk myszy, lub strzałki</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Powiększanie puzzli:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Kółko myszy lub +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Przesuwanie kursora:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Przesuń myszą lub W,A,D,S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>O Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Gra puzzle z części o kształcie tetromina</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Prawo autorskie &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Wydano na licencji &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation>Wybierz wersję OpenGL.</translation>
    </message>
    <message>
        <source>version</source>
        <translation>wersja</translation>
    </message>
</context>
</TS>

==> tetzle_3.0.1.orig.tar.gz: tetzle-3.0.1/translations/tetzle_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Otwórz obraz</translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Skośne krawędzie</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Cienie upuszczania</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Kolory</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Tło:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Cień:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Zaznaczone:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Brak obrazu.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Proszę czekać</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Ładowanie obrazu...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Tworzenie puzzli...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Tworzenie części...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Ładowanie puzzli...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Nieznany format danych</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Nieznany element &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Błąd parsowania pliku XML.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Ładowanie części...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Pobieranie części...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Umieszczanie części...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sukces</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Wybierz grę</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Obecne gry</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Nowa gra</translation>
    </message>
    <message>
        <source>Play Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Właściwości obrazu</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nazwa:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Tagi</translation>
    </message>
    <message>
        <source>New tag name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Wybierz język programu:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Język systemowy&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Uwaga</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Proszę ponownie uruchomić ten program, aby zastosować zmianę języka.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Dodaj obraz</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Usuń obraz</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Właściwości obrazu</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 części</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Kopiowanie obrazów...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Bez tytułu</translation>
    </message>
    <message numerus="yes">
        <source>Remove %n selected image(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Saved games using these image(s) will be deleted.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Bez tytułu</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 części %2 %3% kompletne</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Usuń grę</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Usunąć wybraną grę?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Przegląd</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Dodaj tag</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Usuń tag</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Bez tagów</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Wszystkie obrazy</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Bez tytułu %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pytanie</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Usunąć wybrany tag?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Przepraszamy</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Tag o takiej nazwie już istnieje.</translation>
    </message>
    <message>
        <source>Manage Tags...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Gra</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Pobierz części</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Zakończ</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>W&amp;ybierz...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Widok</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Przybliż</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Oddal</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>&amp;Najlepsze dopasowanie</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Pokaż p&amp;odgląd</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>Pełny &amp;ekran</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ustawienia</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>Wy&amp;gląd...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Język...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Sterowanie</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Sterowanie</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Podnoszenie części:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Lewy przycisk myszy lub spacja</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Upuszczanie części:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Wybór części:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Przeciągając lewym przyciskiem myszy</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Obróć części:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Prawy przycisk myszy, Ctrl + Lewy przycisk myszy lub R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Przeciąganie puzzli:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Środkowy przycisk myszy, Shift + Lewy przycisk myszy, lub strzałki</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Powiększanie puzzli:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Kółko myszy lub +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Przesuwanie kursora:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Przesuń myszą lub W,A,D,S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>O Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Gra puzzle z części o kształcie tetromina</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Prawo autorskie &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Wydano na licencji &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%p% complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>Zoom: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
